@@ -16,9 +16,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 library(testthat)
-library(rstanarm)
+suppressPackageStartupMessages(library(rstanarm))
 Sys.unsetenv("R_TESTS")
-example(example_model)
-test_check("rstanarm", invert = FALSE,
-           filter = if (Sys.getenv("NOT_CRAN") != "true") "stan_functions")
+o <- utils::capture.output(example(example_model, echo = FALSE))
+if (.Platform$OS.type != "windows") { # || .Platform$r_arch != "i386"
+  test_check("rstanarm", invert = FALSE,
+             filter = if (Sys.getenv("NOT_CRAN") != "true") "stan_functions")
+}
 
